import { IRole } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { IConstruct } from 'constructs';
import { AnalyticsEngineVersion, ApacheSparkEngineVersion, AthenaSqlEngineVersion } from './analytics-engine-versions';
import { IAthenaResultEncryption } from './result-encryption';
import { DataSize } from '../../core';
export interface AnalyticsEngineConfiguration {
    readonly encrpytionKey?: IKey;
    readonly enforceConfiguration?: boolean;
    readonly engineVersion?: AnalyticsEngineVersion;
    readonly expectedBucketOwner?: string;
    readonly outputLocation?: string;
    readonly publishMetrics?: boolean;
    readonly queryScannedBytesLimit?: DataSize;
    readonly requesterPays?: boolean;
    readonly resultsBucket?: IBucket;
    readonly resultsBucketEncryptionKey?: IKey;
    readonly resultsBucketEncryptionType?: string;
    readonly role?: IRole;
}
export interface AnalyticsEngineBindProps {
    readonly workGroupName: string;
}
export interface IAnalyticsEngine {
    bind(scope: IConstruct, options: AnalyticsEngineBindProps): AnalyticsEngineConfiguration;
}
export interface AnalyticsEngineOutputOptions {
    readonly bucket?: IBucket;
    readonly encryption?: IAthenaResultEncryption;
    readonly expectedOwnerId?: string;
    readonly keyPrefix?: string;
}
export declare class ApacheSparkEngineOptions {
    readonly encryptionKey?: IKey;
    readonly engineVersion?: ApacheSparkEngineVersion;
    readonly output?: AnalyticsEngineOutputOptions;
    readonly publishMetrics?: boolean;
    readonly role?: IRole;
}
export interface AthenaSqlEngineOptions {
    readonly enforceConfiguration?: boolean;
    readonly engineVersion?: AthenaSqlEngineVersion;
    readonly output?: AnalyticsEngineOutputOptions;
    readonly publishMetrics?: boolean;
    readonly queryScannedBytesLimit?: DataSize;
    readonly requesterPays?: boolean;
}
export declare class AnalyticsEngine {
    static apacheSpark(options: ApacheSparkEngineOptions): IAnalyticsEngine;
    static athenaSql(options?: AthenaSqlEngineOptions): IAnalyticsEngine;
}
