import { IResource, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnIPAMPool } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { AddressConfiguration, IpFamily } from '.';
import { IIpamAllocation, IpamAllocationOptions } from './ipam-allocation';
import { IIpamPoolCidr, IIpamPoolCidrConfiguration } from './ipam-pool-cidr';
import { IIpamScope } from './ipam-scope';
export declare class PublicIpSource {
    readonly name: string;
    static readonly AMAZON: PublicIpSource;
    static readonly BYOIP: PublicIpSource;
    static of(name: string): PublicIpSource;
    private constructor();
}
export interface IIpamPool extends IResource {
    readonly ipamPoolArn: string;
    readonly ipamPoolDepth: number;
    readonly ipamPoolIpamArn: string;
    readonly ipamPoolId: string;
    readonly ipamPoolScopeArn: string;
    readonly ipamPoolScopeType: string;
    readonly ipamPoolState: string;
    readonly ipamPoolStateMessage: string;
    readonly ipFamily: IpFamily;
    addCidrToPool(id: string, options: AddCidrToPoolOptions): AddCidrToPoolResult;
    addChildPool(id: string, options?: AddChildPoolOptions): IIpamPool;
    allocateCidrFromPool(id: string, options?: AllocateCidrFromPoolOptions): IIpamAllocation;
}
export interface IIpv4IpamPool extends IIpamPool {
}
export interface IIpv6IpamPool extends IIpamPool {
}
export interface AddChildPoolOptions {
    readonly addressConfiguration?: AddressConfiguration;
    readonly autoImport?: boolean;
    readonly defaultNetmaskLength?: number;
    readonly maxNetmaskLength?: number;
    readonly minNetmaskLength?: number;
    readonly description?: string;
    readonly locale?: string;
    readonly name?: string;
    readonly provisionedCidrs?: string[];
    readonly tagRestrictions?: {
        [key: string]: string;
    };
}
export interface AddCidrToPoolOptions {
    readonly allowInline?: boolean;
    readonly configuration: IIpamPoolCidrConfiguration;
}
export interface AddCidrToPoolResult {
    readonly cidr?: IIpamPoolCidr;
    readonly inline: boolean;
}
export interface AllocateCidrFromPoolOptions extends IpamAllocationOptions {
    readonly scope?: IConstruct;
}
declare abstract class IpamPoolBase extends Resource implements IIpamPool {
    abstract readonly ipamPoolArn: string;
    abstract readonly ipamPoolDepth: number;
    abstract readonly ipamPoolIpamArn: string;
    abstract readonly ipamPoolId: string;
    abstract readonly ipamPoolScopeArn: string;
    abstract readonly ipamPoolScopeType: string;
    abstract readonly ipamPoolState: string;
    abstract readonly ipamPoolStateMessage: string;
    abstract readonly ipFamily: IpFamily;
    addCidrToPool(id: string, options: AddCidrToPoolOptions): AddCidrToPoolResult;
    addChildPool(id: string, options?: AddChildPoolOptions): IIpamPool;
    allocateCidrFromPool(id: string, options?: AllocateCidrFromPoolOptions): IIpamAllocation;
}
export interface IpamPoolOptions {
    readonly addressConfiguration?: AddressConfiguration;
    readonly autoImport?: boolean;
    readonly description?: string;
    readonly locale?: string;
    readonly name?: string;
    readonly parentPool?: IIpamPool;
    readonly provisionedCidrs?: string[];
    readonly publicIpSource?: PublicIpSource;
    readonly tagRestrictions?: {
        [key: string]: string;
    };
}
export interface IpamPoolProps extends ResourceProps, IpamPoolOptions {
    readonly ipamScope: IIpamScope;
}
export declare class IpamPool extends IpamPoolBase {
    private readonly _provisionedCidrs;
    private readonly _tagRestrictions;
    readonly addressConfiguration: AddressConfiguration;
    readonly autoImport?: boolean;
    readonly description?: string;
    readonly ipamScope: IIpamScope;
    readonly locale?: string;
    readonly name?: string;
    readonly parentPool?: IIpamPool;
    readonly publicIpSource?: PublicIpSource;
    readonly resource: CfnIPAMPool;
    readonly ipamPoolArn: string;
    readonly ipamPoolDepth: number;
    readonly ipamPoolIpamArn: string;
    readonly ipamPoolId: string;
    readonly ipamPoolScopeArn: string;
    readonly ipamPoolScopeType: string;
    readonly ipamPoolState: string;
    readonly ipamPoolStateMessage: string;
    readonly ipFamily: IpFamily;
    constructor(scope: IConstruct, id: string, props: IpamPoolProps);
    addCidrToPool(id: string, options: AddCidrToPoolOptions): AddCidrToPoolResult;
    addChildPool(id: string, options?: AddChildPoolOptions): IIpamPool;
    addTagRestriction(key: string, value: string): IIpamPool;
    protected validateChildLocale(locale?: string): boolean;
    protected validateNestingSupport(): boolean;
}
export {};
