/**
 * Converts an IP address from a dot notation string to an integer.
 *
 * @param dot A string specifying an IP address.
 * @returns The integer equivalent of the input address.
 */
export declare const dot2num: (dot: string) => number;
/**
 * Converts an integer representing an IP address to its equivalent string in
 * dot notation.
 *
 * @param num An integer representing an IP address.
 * @returns The dot notation equivalent of the input address.
 */
export declare const num2dot: (num: number) => string;
/**
 * Checks whether a given string is a valid IPv4 CIDR address.
 *
 * @param cidr A string representing a CIDR block to validate.
 * @returns A boolean indicating whether the given string is a valid IP
 * address or not.
 */
export declare const isValidCidr: (cidr: string) => boolean;
/**
 * Gets the largest netmask which a CIDR can be divided into in order to break
 * the CIDR range into a given number of subnets.
 *
 * @param mask The netmask of the network being divided.
 * @param parts The number of subnets the CIDR will be divided into.
 * @returns The maximum netmask that can be used to get the requested number of
 * subnets from the CIDR range.
 */
export declare const getBiggestMask: (mask: number, parts: number) => number;
/**
 * Gets the total number of IP addresses that would be in a network with a
 * given netmask.
 *
 * @param mask The netmask to get the network size for.
 * @returns The network size of the given netmask.
 */
export declare const getNetworkSize: (mask: number) => number;
/**
 * Divides a CIDR range into a given number of subnets.
 *
 * Subnets will be the largest size possible while staying within bounds of
 * the specified CIDR.
 *
 * @param cidr The CIDR range to divide.
 * @param parts The number of subnets to divide the CIDR range into.
 * @param mask The netmask to use for the generate subnets.
 * @returns CIDR ranges for the requested number of subnets.
 */
export declare const divideCidr: (cidr: string, parts: number, mask?: number | undefined) => string[];
